==> nodejs_interop-0.8.0.tar.gz: test/node/buffer/buffer_test.dart <==
import 'dart:convert';
import 'dart:typed_data';
import 'package:nodejs_interop/node.dart';
import 'package:test/test.dart';

/// Tests the features of the [Buffer] class.
void main() => group('Buffer', () {
  group('.BYTES_PER_ELEMENT', () {
    test('should return `1`', () {
      expect(Buffer.BYTES_PER_ELEMENT, equals(1));
    });
  });

  group('.name', () {
    test('should return "Buffer"', () {
      expect(Buffer.name, equals('Buffer'));
    });
  });

  group('.alloc()/.allocUnsafe()/.allocUnsafeSlow()', () {
    test('should allocate an amount of memory equal to the given size', () {
      expect(Buffer.alloc(1024), hasLength(1024));
      expect(Buffer.allocUnsafe(4096), hasLength(4096));
      expect(Buffer.allocUnsafeSlow(8192), hasLength(8192));
    });
  });

  group('.byteLength()', () {
    test('should return the byte length of a string', () {
      expect(Buffer.byteLength(''), equals(0));
      expect(Buffer.byteLength('CedX'), equals(4));
      expect(Buffer.byteLength('Cédric'), equals(7));
    });
  });

  group('.compare()', () {
    test('should return `0` if the given buffers are equal', () {
      var buffer = Buffer.from('foo');
      expect(Buffer.compare(buffer, Buffer.from(buffer)), equals(0));
    });

    test('should return a positive number if the source buffer is after the given one', () {
      expect(Buffer.compare(Buffer.from('foo'), Buffer.from('bar')), isPositive);
    });

    test('should return a negative number if the source buffer is before the given one', () {
      expect(Buffer.compare(Buffer.from('bar'), Buffer.from('foo')), isNegative);
    });
  });

  group('.concat()', () {
    test('should return a new buffer which is the result of concatenating the given buffer list', () {
      var buffer = Buffer.concat(<Uint8List>[Buffer.from('foo'), Buffer.from(''), Buffer.from('Bar')]);
      expect(UTF8.decode(buffer), equals('fooBar'));
    });
  });

  group('.from()', () {
    test('should return a buffer from a list of octets', () {
      var bytes = const [102, 111, 111, 66, 97, 114];
      var buffer = Buffer.from(bytes);
      expect(buffer, orderedEquals(bytes));
      expect(UTF8.decode(buffer), equals('fooBar'));
    });

    test('should return a copy of the given buffer', () {
      var bytes = const [102, 111, 111, 66, 97, 114];
      var source = Buffer.from(bytes);

      var buffer = Buffer.from(source);
      expect(buffer, orderedEquals(bytes));

      source[3] = 98;
      expect(source, orderedEquals(<int>[102, 111, 111, 98, 97, 114]));
      expect(buffer, orderedEquals(bytes));
    });

    test('should return a buffer from a string', () {
      var buffer = Buffer.from('fooBar');
      expect(buffer, orderedEquals(<int>[102, 111, 111, 66, 97, 114]));
      expect(UTF8.decode(buffer), equals('fooBar'));
    });

  });

  group('.isBuffer()', () {
    test('should return `true` for a `Buffer` object', () {
      expect(Buffer.isBuffer('foo'), isFalse);
      expect(Buffer.isBuffer(['foo', 'bar']), isFalse);

      expect(Buffer.isBuffer(Buffer.from('foo')), isTrue);
      expect(Buffer.isBuffer(Buffer.from(['foo', 'bar'])), isTrue);
    });
  });

  group('.isEncoding()', () {
    test('should return `true` for a supported encoding', () {
      expect(Buffer.isEncoding('foo'), isFalse);
      expect(Buffer.isEncoding(BufferEncoding.buffer), isFalse);

      expect(Buffer.isEncoding(BufferEncoding.latin1), isTrue);
      expect(Buffer.isEncoding(BufferEncoding.utf8), isTrue);
    });
  });
});

==> nodejs_interop-0.9.0.tar.gz: test/node/buffer/buffer_test.dart <==
import 'dart:convert';
import 'dart:typed_data';
import 'package:nodejs_interop/node.dart';
import 'package:test/test.dart';

/// Tests the features of the [Buffer] class.
void main() => group('Buffer', () {
  group('.BYTES_PER_ELEMENT', () {
    test('should return `1`', () {
      expect(Buffer.BYTES_PER_ELEMENT, equals(1));
    });
  });

  group('.name', () {
    test('should return "Buffer"', () {
      expect(Buffer.name, equals('Buffer'));
    });
  });

  group('.alloc()/.allocUnsafe()/.allocUnsafeSlow()', () {
    test('should allocate an amount of memory equal to the given size', () {
      expect(Buffer.alloc(1024), hasLength(1024));
      expect(Buffer.allocUnsafe(4096), hasLength(4096));
      expect(Buffer.allocUnsafeSlow(8192), hasLength(8192));
    });
  });

  group('.byteLength()', () {
    test('should return the byte length of a string', () {
      expect(Buffer.byteLength(''), equals(0));
      expect(Buffer.byteLength('CedX'), equals(4));
      expect(Buffer.byteLength('Cédric'), equals(7));
    });
  });

  group('.compare()', () {
    test('should return `0` if the given buffers are equal', () {
      var buffer = Buffer.from('foo');
      expect(Buffer.compare(buffer, Buffer.from(buffer)), equals(0));
    });

    test('should return a positive number if the source buffer is after the given one', () {
      expect(Buffer.compare(Buffer.from('foo'), Buffer.from('bar')), isPositive);
    });

    test('should return a negative number if the source buffer is before the given one', () {
      expect(Buffer.compare(Buffer.from('bar'), Buffer.from('foo')), isNegative);
    });
  });

  group('.concat()', () {
    test('should return a new buffer which is the result of concatenating the given buffer list', () {
      var buffer = Buffer.concat(<Uint8List>[Buffer.from('foo'), Buffer.from(''), Buffer.from('Bar')]);
      expect(utf8.decode(buffer), equals('fooBar'));
    });
  });

  group('.from()', () {
    test('should return a buffer from a list of octets', () {
      var bytes = const [102, 111, 111, 66, 97, 114];
      var buffer = Buffer.from(bytes);
      expect(buffer, orderedEquals(bytes));
      expect(utf8.decode(buffer), equals('fooBar'));
    });

    test('should return a copy of the given buffer', () {
      var bytes = const [102, 111, 111, 66, 97, 114];
      var source = Buffer.from(bytes);

      var buffer = Buffer.from(source);
      expect(buffer, orderedEquals(bytes));

      source[3] = 98;
      expect(source, orderedEquals(<int>[102, 111, 111, 98, 97, 114]));
      expect(buffer, orderedEquals(bytes));
    });

    test('should return a buffer from a string', () {
      var buffer = Buffer.from('fooBar');
      expect(buffer, orderedEquals(<int>[102, 111, 111, 66, 97, 114]));
      expect(utf8.decode(buffer), equals('fooBar'));
    });

  });

  group('.isBuffer()', () {
    test('should return `true` for a `Buffer` object', () {
      expect(Buffer.isBuffer('foo'), isFalse);
      expect(Buffer.isBuffer(['foo', 'bar']), isFalse);

      expect(Buffer.isBuffer(Buffer.from('foo')), isTrue);
      expect(Buffer.isBuffer(Buffer.from(['foo', 'bar'])), isTrue);
    });
  });

  group('.isEncoding()', () {
    test('should return `true` for a supported encoding', () {
      expect(Buffer.isEncoding('foo'), isFalse);
      expect(Buffer.isEncoding(BufferEncoding.buffer), isFalse);

      expect(Buffer.isEncoding(BufferEncoding.latin1), isTrue);
      expect(Buffer.isEncoding(BufferEncoding.utf8), isTrue);
    });
  });
});
